@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -35,6 +35,12 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2012-10-29 - v1.008
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.025.
+
+=item *
+
 2012-10-22 - v1.007
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.024.
@@ -1185,6 +1191,7 @@ BLNOARD
 BLOGALEX
 BLOM
 BLOONIX
+BLOPEZ
 BLSRM
 BLUECURIO
 BLUEFEET
@@ -2394,6 +2401,7 @@ DISHMAEL
 DISSENT
 DIST
 DISTLER
+DITTO
 DIVEC
 DIVER
 DIVERDI
@@ -3059,6 +3067,7 @@ FERRANCE
 FERREIRA
 FERRENCY
 FERZ
+FESTY
 FEUERBACH
 FFAUTEUX
 FGA
@@ -3409,6 +3418,7 @@ GLIDER
 GLMEOCCI
 GLORYBOX
 GLOVER
+GLTS
 GMAMBRO
 GMAX
 GMCC
@@ -3703,6 +3713,7 @@ HEIKOK
 HEIKOWU
 HEINZEBA
 HEJKI
+HELEI
 HELENA
 HELLERM
 HELLMAN
@@ -3882,6 +3893,7 @@ HUNTER
 HUSKA
 HUSOFT
 HUXTONR
+HVALVERDE
 HVC
 HVDS
 HVOERS
@@ -4702,6 +4714,7 @@ JONTY
 JOOON
 JORDAN
 JORISVR
+JOROL
 JOROURKE
 JORVIS
 JOS
@@ -4845,6 +4858,7 @@ JTOBEY
 JTOPJIAN
 JTP
 JTPALMER
+JTRAJ
 JTRAMMELL
 JTROWE
 JTT
@@ -4931,6 +4945,7 @@ KAHN
 KAHUNA
 KAIH
 KAILI
+KAIMI
 KAIW
 KAKADU
 KAKE
@@ -5770,6 +5785,7 @@ MALLEN
 MALLRED
 MALLUM
 MALO
+MALOHIN
 MALPOETA
 MALT
 MALTEU
@@ -6024,6 +6040,7 @@ MCGREGOR
 MCGRUFF
 MCHANG
 MCHAPMAN
+MCHE
 MCHING
 MCKAY
 MCLANDER
@@ -7130,6 +7147,7 @@ PARVEZ
 PASHA
 PASKY
 PASP
+PASSANI
 PASSOS
 PASTI
 PATBAKER
@@ -7240,6 +7258,7 @@ PERLBOTIX
 PERLBOY
 PERLCHINA
 PERLDL
+PERLEONE
 PERLER
 PERLGIRL
 PERLISH
@@ -8240,6 +8259,7 @@ SARFY
 SARGE
 SARGIE
 SARTAK
+SASAKURE
 SASAO
 SASATA
 SASAZUKA
@@ -9079,6 +9099,7 @@ TAFFY
 TAG
 TAGESTAD
 TAGOMORIS
+TAILRIVER
 TAIY
 TAKADONET
 TAKASH
@@ -9111,6 +9132,7 @@ TANIMOTO
 TANTALOR
 TAO
 TAPASRB
+TAPPER
 TARAO
 TAREKA
 TARO
@@ -9304,6 +9326,7 @@ TJUGO
 TJWALKER
 TJYANG
 TKEEFER
+TKEMMER
 TKHARRIS
 TKISHEL
 TKLEIN
@@ -9364,6 +9387,7 @@ TODD
 TODDAG
 TODDR
 TOJO
+TOKAR
 TOKAREV
 TOKUBASS
 TOKUHIROM
@@ -9531,11 +9555,13 @@ TWH
 TWIBBLER
 TWID
 TWILDE
+TWILLERT
 TWINKLE
 TWITTEK
 TWIX
 TWRIGHT
 TWYLIE
+TXIWASAKI
 TYANO
 TYEGAH
 TYEMQ
@@ -10214,6 +10240,7 @@ ZHANGXIN
 ZHDA
 ZHIRSCH
 ZHLONG
+ZHOUBO
 ZHOUXIN
 ZHR
 ZHUANGLI
